diff --git a/index.html b/index.html
index 62fc52e..fd55482 100644
--- a/index.html
+++ b/index.html
@@ -113,7 +113,7 @@
ALT-[0-9]: Focus on buffer
ALT-a: Focus on next buffer with activity
ALT-<: Switch to previous buffer
- CTRL+G: Focus on buffer list filter
+ ALT+G: Focus on buffer list filter
escape: disconnect
arrow keys: history navigation
diff --git a/js/glowingbear.js b/js/glowingbear.js
index 8b075e8..e984be1 100644
--- a/js/glowingbear.js
+++ b/js/glowingbear.js
@@ -1056,8 +1056,8 @@ weechat.directive('inputBar', function() {
return true;
}
- // Ctrl+G -> focus on buffer filter input
- if ($event.ctrlKey && (code === 103 || code === 71)) {
+ // Alt+G -> focus on buffer filter input
+ if ($event.altKey && (code === 103 || code === 71)) {
$event.preventDefault();
document.getElementById('bufferFilter').focus();
return true;